@@ -29,10 +29,8 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
     @credentials.password = neutron_credentials['password']
     @credentials.project_name = neutron_credentials['project_name']
     @credentials.auth_url = auth_endpoint
-    if @credentials.version == '3'
-      @credentials.user_domain_name = neutron_credentials['user_domain_name']
-      @credentials.project_domain_name = neutron_credentials['project_domain_name']
-    end
+    @credentials.user_domain_name = neutron_credentials['user_domain_name']
+    @credentials.project_domain_name = neutron_credentials['project_domain_name']
     if neutron_credentials['region_name']
       @credentials.region_name = neutron_credentials['region_name']
     end
@@ -81,19 +79,23 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
         auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
       creds = Hash[ auth_keys.map \
                    { |k| [k, conf['keystone_authtoken'][k].strip] } ]
-      if conf['neutron'] and conf['neutron']['region_name']
-        creds['region_name'] = conf['neutron']['region_name'].strip
+
+      if !conf['keystone_authtoken']['region_name'].nil?
+        creds['region_name'] = conf['keystone_authtoken']['region_name'].strip
       end
+
       if !conf['keystone_authtoken']['project_domain_name'].nil?
         creds['project_domain_name'] = conf['keystone_authtoken']['project_domain_name'].strip
       else
         creds['project_domain_name'] = 'Default'
       end
+
       if !conf['keystone_authtoken']['user_domain_name'].nil?
         creds['user_domain_name'] = conf['keystone_authtoken']['user_domain_name'].strip
       else
         creds['user_domain_name'] = 'Default'
       end
+
       return creds
     else
       raise(Puppet::Error, "File: #{conf_filename} does not contain all " +
@@ -236,7 +238,7 @@ class Puppet::Provider::Neutron < Puppet::Provider::Openstack
       instance = Puppet::Type.type(instance_type).instances.find do |i|
         # We need to check against the Default domain name because of
         # https://review.opendev.org/#/c/226919/ which changed the naming
-        # format for the tenant to include ::<Domain name>. This should be
+        # format for the tenant to include <Domain name>. This should be
         # removed when we drop the resource without a domain name.
         # TODO(aschultz): remove ::domain lookup as part of M-cycle
         i.provider.name == name || i.provider.name == "#{name}::#{domain}"
