@@ -1,10 +1,16 @@
+# DEPRECATED!
 Puppet::Type.type(:neutron_fwaas_service_config).provide(
   :ini_setting,
   :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
 ) do
 
-  def file_path
+  def self.file_path
     '/etc/neutron/fwaas_driver.ini'
   end
 
+  # added for backwards compatibility with older versions of inifile
+  def file_path
+    self.class.file_path
+  end
+
 end
