@@ -25,8 +25,8 @@ Puppet::Type.newtype(:neutron_plugin_cisco_l2network) do
     ['/etc/neutron/plugins/cisco']
   end
 
-  autorequire(:package) do
-    'neutron-plugin-cisco'
+  autorequire(:anchor) do
+    ['neutron::install::end']
   end
 
 end
