@@ -16,8 +16,17 @@ Puppet::Type.newtype(:neutron_plugin_nuage) do
     end
   end
 
-  autorequire(:package) do
-    'neutron-plugin-nuage'
+  newparam(:ensure_absent_val) do
+    desc 'A value that is specified as the value property will behave as if ensure => absent was specified'
+    defaultto('<SERVICE DEFAULT>')
+  end
+
+  autorequire(:anchor) do
+    ['neutron::install::end']
+  end
+
+  autorequire(:file) do
+    '/etc/neutron/plugins/nuage/plugin.ini'
   end
 
 end
