@@ -12,7 +12,9 @@ Puppet::Type.newtype(:neutron_plugin_sriov) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do ['neutron'] end
+  autorequire(:anchor) do
+    ['neutron::install::end']
+  end
 
   newproperty(:value) do
     desc 'The value of the setting to be defined.'
