@@ -64,8 +64,8 @@ Puppet::Type.newtype(:neutron_router) do
     desc 'A uuid identifying the tenant which will own the router.'
   end
 
-  autorequire(:service) do
-    ['neutron-server']
+  autorequire(:anchor) do
+    ['neutron::service::end']
   end
 
   autorequire(:keystone_tenant) do
@@ -92,6 +92,10 @@ Puppet::Type.newtype(:neutron_router) do
     end
   end
 
+  newproperty(:availability_zone_hint) do
+    desc 'The availability zone hint to provide the scheduler'
+  end
+
   validate do
     if self[:ensure] != :present
       return
