@@ -34,8 +34,8 @@ Puppet::Type.newtype(:neutron_security_group) do
   end
 
   # Require the neutron-server service to be running
-  autorequire(:service) do
-    ['neutron-server']
+  autorequire(:anchor) do
+    ['neutron::service::end']
   end
 
   newparam(:name, :namevar => true) do
