@@ -32,12 +32,13 @@ describe 'neutron::agents::l3' do
     it 'configures l3_agent.ini' do
       should contain_neutron_l3_agent_config('DEFAULT/debug').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/interface_driver').with_value(p[:interface_driver])
-      should contain_neutron_l3_agent_config('DEFAULT/gateway_external_network_id').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/handle_internal_only_routers').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/metadata_port').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/periodic_interval').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/periodic_fuzzy_delay').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('DEFAULT/enable_metadata_proxy').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('DEFAULT/radvd_user').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_l3_agent_config('ovs/integration_bridge').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/availability_zone').with_value('<SERVICE DEFAULT>')
       should contain_neutron_l3_agent_config('agent/extensions').with_value('<SERVICE DEFAULT>')
     end
@@ -88,6 +89,16 @@ describe 'neutron::agents::l3' do
       end
     end
 
+    context 'with radvd user' do
+      before :each do
+        params.merge!(:radvd_user => 'root')
+      end
+
+      it 'configures radvd user' do
+        should contain_neutron_l3_agent_config('DEFAULT/radvd_user').with_value(p[:radvd_user])
+      end
+    end
+
     context 'with HA routers' do
       before :each do
         params.merge!(:ha_enabled            => true,
@@ -100,6 +111,15 @@ describe 'neutron::agents::l3' do
       end
     end
 
+    context 'with ovs_integration_bridge' do
+      before :each do
+        params.merge!(:ovs_integration_bridge => 'br-int')
+      end
+      it 'should configure ovs_integration_bridge' do
+        should contain_neutron_l3_agent_config('ovs/integration_bridge').with_value(p[:ovs_integration_bridge])
+      end
+    end
+
     context 'with availability zone' do
       before :each do
         params.merge!(:availability_zone => 'zone1')
