@@ -57,7 +57,7 @@ describe 'neutron::agents::ovn_metadata' do
       should contain_ovn_metadata_agent_config('DEFAULT/nova_metadata_host').with(:value => '<SERVICE DEFAULT>')
       should contain_ovn_metadata_agent_config('DEFAULT/nova_metadata_port').with(:value => '<SERVICE DEFAULT>')
       should contain_ovn_metadata_agent_config('DEFAULT/nova_metadata_protocol').with(:value => '<SERVICE DEFAULT>')
-      should contain_ovn_metadata_agent_config('DEFAULT/metadata_workers').with(:value => facts[:os_workers])
+      should contain_ovn_metadata_agent_config('DEFAULT/metadata_workers').with(:value => 2)
       should contain_ovn_metadata_agent_config('DEFAULT/metadata_backlog').with(:value => '<SERVICE DEFAULT>')
       should contain_ovn_metadata_agent_config('DEFAULT/nova_metadata_insecure').with(:value => '<SERVICE DEFAULT>')
       should contain_ovn_metadata_agent_config('DEFAULT/state_path').with(:value => params[:state_path])
@@ -67,6 +67,7 @@ describe 'neutron::agents::ovn_metadata' do
       should contain_ovn_metadata_agent_config('ovs/ovsdb_connection_timeout').with(:value => '<SERVICE DEFAULT>')
       should contain_ovn_metadata_agent_config('ovs/ovsdb_connection').with(:value => params[:ovsdb_connection])
       should contain_ovn_metadata_agent_config('ovn/ovn_sb_connection').with(:value => '<SERVICE DEFAULT>')
+      should contain_ovn_metadata_agent_config('ovn/ovn_remote_probe_interval').with(:value => '<SERVICE DEFAULT>')
     end
   end
 
@@ -119,10 +120,18 @@ describe 'neutron::agents::ovn_metadata' do
             :ovn_metadata_agent_service => 'networking-ovn-metadata-agent'
           }
         when 'RedHat'
-          {
-            :ovn_metadata_agent_package => 'python-networking-ovn-metadata-agent',
-            :ovn_metadata_agent_service => 'networking-ovn-metadata-agent'
-          }
+          if facts[:operatingsystem] == 'Fedora'
+            { :ovn_metadata_agent_package => 'python3-networking-ovn-metadata-agent',
+              :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :ovn_metadata_agent_package => 'python3-networking-ovn-metadata-agent',
+                :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
+            else
+              { :ovn_metadata_agent_package => 'python-networking-ovn-metadata-agent',
+                :ovn_metadata_agent_service => 'networking-ovn-metadata-agent' }
+            end
+          end
         end
       end
 
