@@ -30,7 +30,7 @@ describe 'neutron::plugins::ml2::fujitsu' do
     it 'should have' do
       should contain_package('python-networking-fujitsu').with(
         :ensure => params[:package_ensure],
-        :tag    => 'openstack'
+        :tag    => ['openstack', 'neutron-plugin-ml2-package']
         )
     end
   end
