@@ -22,10 +22,10 @@ describe 'neutron::plugins::ml2::networking_baremetal' do
       should contain_package('python2-networking-baremetal').with(
         :name   => platform_params[:networking_baremetal_package],
         :ensure => p[:package_ensure],
-        :tag    => ['openstack', 'neutron-package'],
+        :tag    => ['openstack', 'neutron-plugin-ml2-package'],
       )
       should contain_package('python2-networking-baremetal').that_requires('Anchor[neutron::install::begin]')
-      should contain_package('python2-networking-baremetal').that_notifies('Anchor[neutron::install::end]')
+      should contain_package('python2-networking-baremetal').that_notifies('Anchor[neutron::config::end]')
     end
   end
 
