@@ -87,6 +87,39 @@ tenant_id="60f9544eb94c42a6b7e8e98c2be981b1"'
     end
   end
 
+  describe 'when creating a subnet with neutronclient >= 6.1.0' do
+    it 'should call subnet-create with appropriate command line options' do
+      provider.class.stubs(:get_tenant_id).returns(subnet_attrs[:tenant_id])
+
+      output = 'Created a new subnet:
+allocation_pools="[{u\'start\': u\'10.0.0.2\', u\'end\': u\'10.0.0.10\'}]"
+cidr="10.0.0.0/24"
+dns_nameservers="[u\'8.8.8.8\']"
+enable_dhcp="False"
+gateway_ip="10.0.0.1"
+host_routes="[{u\'destination\': u\'12.0.0.0/24\', u\'nexthop\': u\'10.0.0.1\'}]"
+id="dd5e0ef1-2c88-4b0b-ba08-7df65be87963"
+ip_version="4"
+name="net1"
+network_id="98873773-aa34-4b87-af05-70903659246f"
+tenant_id="60f9544eb94c42a6b7e8e98c2be981b1"'
+
+      provider.expects(:auth_neutron).with('subnet-create', '--format=shell',
+                                            ["--name=#{subnet_attrs[:name]}",
+                                             "--ip-version=#{subnet_attrs[:ip_version]}",
+                                             "--gateway-ip=#{subnet_attrs[:gateway_ip]}",
+                                             "--disable-dhcp",
+                                             "--allocation-pool=#{subnet_attrs[:allocation_pools]}",
+                                             "--dns-nameserver=#{subnet_attrs[:dns_nameservers]}",
+                                             "--host-route=#{subnet_attrs[:host_routes]}",
+                                             "--tenant_id=#{subnet_attrs[:tenant_id]}",
+                                             subnet_name],
+                                           subnet_attrs[:cidr]).returns(output)
+
+      provider.create
+    end
+  end
+
   describe 'when creating a ipv6 subnet' do
 
     let :resource do
