@@ -23,12 +23,12 @@ describe 'Puppet::Type.type(:neutron_api_paste_ini)' do
 
   it 'should autorequire the package that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'neutron')
-    catalog.add_resource package, @neutron_api_paste_ini
+    anchor = Puppet::Type.type(:anchor).new(:name => 'neutron::install::end')
+    catalog.add_resource anchor, @neutron_api_paste_ini
     dependency = @neutron_api_paste_ini.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@neutron_api_paste_ini)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
